package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.GeneralName;
import java.util.Enumeration;

public class PKIHeader extends ASN1Encodable {
   private DERInteger pvno;
   private GeneralName sender;
   private GeneralName recipient;
   private DERGeneralizedTime messageTime;
   private AlgorithmIdentifier protectionAlg;
   private ASN1OctetString senderKID;
   private ASN1OctetString recipKID;
   private ASN1OctetString transactionID;
   private ASN1OctetString senderNonce;
   private ASN1OctetString recipNonce;
   private PKIFreeText freeText;
   private ASN1Sequence generalInfo;

   private PKIHeader(ASN1Sequence seq) {
      Enumeration seq1;
      this.pvno = DERInteger.getInstance((seq1 = seq.getObjects()).nextElement());
      this.sender = GeneralName.getInstance(seq1.nextElement());
      this.recipient = GeneralName.getInstance(seq1.nextElement());

      while(seq1.hasMoreElements()) {
         ASN1TaggedObject var2;
         switch ((var2 = (ASN1TaggedObject)seq1.nextElement()).getTagNo()) {
            case 0:
               this.messageTime = DERGeneralizedTime.getInstance(var2, true);
               break;
            case 1:
               this.protectionAlg = AlgorithmIdentifier.getInstance(var2, true);
               break;
            case 2:
               this.senderKID = ASN1OctetString.getInstance(var2, true);
               break;
            case 3:
               this.recipKID = ASN1OctetString.getInstance(var2, true);
               break;
            case 4:
               this.transactionID = ASN1OctetString.getInstance(var2, true);
               break;
            case 5:
               this.senderNonce = ASN1OctetString.getInstance(var2, true);
               break;
            case 6:
               this.recipNonce = ASN1OctetString.getInstance(var2, true);
               break;
            case 7:
               this.freeText = PKIFreeText.getInstance(var2, true);
               break;
            case 8:
               this.generalInfo = ASN1Sequence.getInstance(var2, true);
               break;
            default:
               throw new IllegalArgumentException("unknown tag number: " + var2.getTagNo());
         }
      }

   }

   public static PKIHeader getInstance(Object o) {
      if (o instanceof PKIHeader) {
         return (PKIHeader)o;
      } else if (o instanceof ASN1Sequence) {
         return new PKIHeader((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   private void addOptional(ASN1EncodableVector v, int tagNo, ASN1Encodable obj) {
      if (obj != null) {
         DERTaggedObject var4;
         var4 = new DERTaggedObject.<init>(true, tagNo, obj);
         v.add(var4);
      }

   }

   public DERInteger getPvno() {
      return this.pvno;
   }

   public GeneralName getSender() {
      return this.sender;
   }

   public GeneralName getRecipient() {
      return this.recipient;
   }

   public DERObject toASN1Object() {
      PKIHeader var10000 = this;
      PKIHeader var10001 = this;
      PKIHeader var10002 = this;
      PKIHeader var10003 = this;
      PKIHeader var10004 = this;
      PKIHeader var10005 = this;
      PKIHeader var10006 = this;
      PKIHeader var10007 = this;
      PKIHeader var10008 = this;
      PKIHeader var10009 = this;
      PKIHeader var10010 = this;
      PKIHeader var10011 = this;
      PKIHeader var10012 = this;
      PKIHeader var10013 = this;
      PKIHeader var10014 = this;
      PKIHeader var10015 = this;
      PKIHeader var10016 = this;
      ASN1EncodableVector var1;
      ASN1EncodableVector var10018 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.pvno);
      var1.add(this.sender);
      var10018.add(this.recipient);
      DERGeneralizedTime var2 = this.messageTime;
      var10016.addOptional(var1, 0, var2);
      AlgorithmIdentifier var3 = var10015.protectionAlg;
      var10014.addOptional(var1, 1, var3);
      ASN1OctetString var4 = var10013.senderKID;
      var10012.addOptional(var1, 2, var4);
      var4 = var10011.recipKID;
      var10010.addOptional(var1, 3, var4);
      var4 = var10009.transactionID;
      var10008.addOptional(var1, 4, var4);
      var4 = var10007.senderNonce;
      var10006.addOptional(var1, 5, var4);
      var4 = var10005.recipNonce;
      var10004.addOptional(var1, 6, var4);
      PKIFreeText var5 = var10003.freeText;
      var10002.addOptional(var1, 7, var5);
      ASN1Sequence var6 = var10001.generalInfo;
      var10000.addOptional(var1, 8, var6);
      return new DERSequence(var1);
   }
}
